@@ -1,6 +1,6 @@
 /* get_fr.c -- Return the center of an interval as a floating point.
 
-Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2010,
+Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2010, 2011,
                      Spaces project, Inria Lorraine
                      and Salsa project, INRIA Rocquencourt,
                      and Arenaire project, Inria Rhone-Alpes, France
@@ -28,6 +28,5 @@ MA 02110-1301, USA. */
 void
 mpfi_get_fr (mpfr_ptr m, mpfi_srcptr a)
 {
-  int dummy;
-  dummy = mpfi_mid (m, a);
+  mpfi_mid (m, a);
 }
